FsckIssueKind

Enum FsckIssueKind 

pub enum FsckIssueKind {
Show 31 variants OversizedRecordMetadata, InvalidRecordJson, InvalidFileId, InvalidContentHash, RecordPathMismatch, NonContiguousChunks, EmptyChunk, TotalBytesMismatch, InvalidChunkRange, InvalidPackedRange, RecordHashMismatch, MissingChunk, ChunkHashMismatch, ChunkLengthMismatch, MissingVersionRecord, MismatchedVersionRecord, MissingDedupeShardObject, InvalidRetainedShard, InvalidDedupeShardMapping, EmptyReconstruction, MissingReconstructionXorb, InvalidQuarantineCandidate, MissingQuarantinedObject, QuarantineLengthMismatch, ReachableQuarantinedObject, InvalidRetentionHold, MissingHeldObject, HeldQuarantinedObject, InvalidWebhookDeliveryTimestamp, InvalidProviderRepositoryState, InvalidProviderRepositoryStateTimestamp,
}
Integrity issue kinds for the checker.

Variants



OversizedRecordMetadata

Record metadata exceeded the bounded parser ceiling.



InvalidRecordJson

Record bytes were not valid JSON.



InvalidFileId

Record file identifier failed validation.



InvalidContentHash

Record content hash failed validation.



RecordPathMismatch

Record was stored at an unexpected path.



NonContiguousChunks

Record chunk offsets were not contiguous.



EmptyChunk

Record contained an empty chunk term.



TotalBytesMismatch

Record total byte count did not match chunk lengths.



InvalidChunkRange

Record contained an empty or inverted xorb chunk range.



InvalidPackedRange

Record contained an empty or inverted packed xorb byte range.



RecordHashMismatch

Record content hash did not match reconstructed metadata hash.



MissingChunk

Referenced chunk bytes were missing.



ChunkHashMismatch

Referenced chunk body did not hash to the declared chunk hash.



ChunkLengthMismatch

Referenced chunk byte length did not match the record.



MissingVersionRecord

Visible latest record did not have a matching immutable version record.



MismatchedVersionRecord

Visible latest record differed from its immutable version record.



MissingDedupeShardObject

Indexed retained-shard object was missing from object storage.



InvalidRetainedShard

Indexed retained-shard object could not be parsed as a native Xet shard.



InvalidDedupeShardMapping

Indexed retained-shard object did not contain the mapped chunk hash.



EmptyReconstruction

Durable reconstruction metadata did not contain any terms.



MissingReconstructionXorb

Durable reconstruction metadata referenced an unregistered xorb.



InvalidQuarantineCandidate

Quarantine metadata had an invalid retention timeline.



MissingQuarantinedObject

Quarantine metadata referenced an object that no longer existed.



QuarantineLengthMismatch

Quarantine metadata length disagreed with current object metadata.



ReachableQuarantinedObject

Quarantine metadata still targeted a reachable live object.



InvalidRetentionHold

Retention-hold metadata had an invalid timeline.



MissingHeldObject

An active retention hold referenced an object that no longer existed.



HeldQuarantinedObject

An active retention hold still coexisted with quarantine state for the same object.



InvalidWebhookDeliveryTimestamp

A processed webhook delivery had a timestamp too far in the future.



InvalidProviderRepositoryState

Provider repository lifecycle metadata had an invalid repository identity.



InvalidProviderRepositoryStateTimestamp

Provider repository lifecycle metadata had a timestamp too far in the future.

Implementations

Source

impl FsckIssueKind

pub const fn as_str(self) -> &'static str

Stable issue label for CLI and logs.