bazel_cache_object_key

Function bazel_cache_object_key 

pub fn bazel_cache_object_key(
    kind: BazelCacheKind,
    hash_hex: &str,
    repository_scope: Option<&RepositoryScope>,
) -> Result<ObjectKey, ProtocolError>
Returns the storage object key for a Bazel cache entry.

Errors

Returns ProtocolError::InvalidContentHash when hash_hex is malformed or the constructed key is invalid.