pub struct FuzzBazelHttpFrontendSummary {
pub ac_accepts: bool,
pub cas_accepts: bool,
}Expand description
Summary of Bazel HTTP cache frontend validation used by fuzz targets.
Fields
ac_accepts: boolWhether the supplied hash is accepted for ac objects.
cas_accepts: boolWhether the supplied hash is accepted for cas objects.