pub struct FuzzProtocolFrontendSummary {
pub frontend_accepts: bool,
pub digest_accepts: bool,
pub lfs_accepts: bool,
pub bazel_accepts: bool,
pub oci_repository_accepts: bool,
pub oci_reference_accepts: bool,
pub oci_blob_accepts: bool,
pub oci_manifest_accepts: bool,
}Expand description
Summary of protocol-frontend parser and key validation used by fuzz targets.
Fields
frontend_accepts: boolWhether the frontend selector token parsed successfully.
digest_accepts: boolWhether the digest parser accepted the supplied digest string.
lfs_accepts: boolWhether the Git LFS object-key derivation accepted the supplied oid.
bazel_accepts: boolWhether the Bazel cache key derivation accepted the supplied hash.
oci_repository_accepts: boolWhether the OCI repository validator accepted the repository name.
oci_reference_accepts: boolWhether the OCI tag/reference validator accepted the supplied reference.
oci_blob_accepts: boolWhether the OCI blob key derivation accepted the input tuple.
oci_manifest_accepts: boolWhether the OCI manifest key derivation accepted the input tuple.