pub struct LifecycleRepairReport {
pub scanned_records: u64,
pub referenced_objects: u64,
pub scanned_quarantine_candidates: u64,
pub removed_missing_quarantine_candidates: u64,
pub removed_reachable_quarantine_candidates: u64,
pub removed_held_quarantine_candidates: u64,
pub scanned_retention_holds: u64,
pub removed_expired_retention_holds: u64,
pub removed_missing_retention_holds: u64,
pub scanned_webhook_deliveries: u64,
pub removed_stale_webhook_deliveries: u64,
pub removed_future_webhook_deliveries: u64,
}Expand description
Lifecycle-repair report.
Fields
scanned_records: u64Number of file and file-version records scanned to derive reachability.
referenced_objects: u64Number of distinct object keys found reachable from current live metadata.
scanned_quarantine_candidates: u64Number of quarantine candidates inspected.
removed_missing_quarantine_candidates: u64Number of quarantine candidates removed because the object was already missing.
removed_reachable_quarantine_candidates: u64Number of quarantine candidates removed because the object was reachable again.
removed_held_quarantine_candidates: u64Number of quarantine candidates removed because an active hold protected the object.
scanned_retention_holds: u64Number of retention holds inspected.
removed_expired_retention_holds: u64Number of expired retention holds removed.
removed_missing_retention_holds: u64Number of retention holds removed because the protected object was already missing.
scanned_webhook_deliveries: u64Number of webhook delivery claims inspected.
removed_stale_webhook_deliveries: u64Number of webhook delivery claims removed because they were older than the configured retention.
removed_future_webhook_deliveries: u64Number of webhook delivery claims removed because they were far in the future.