pub struct LocalGcReport {
pub scanned_records: u64,
pub referenced_chunks: u64,
pub orphan_chunks: u64,
pub orphan_chunk_bytes: u64,
pub active_quarantine_candidates: u64,
pub new_quarantine_candidates: u64,
pub retained_quarantine_candidates: u64,
pub released_quarantine_candidates: u64,
pub deleted_chunks: u64,
pub deleted_bytes: u64,
}Expand description
Local filesystem garbage-collection report.
Fields
scanned_records: u64Number of file and file-version records scanned.
referenced_chunks: u64Number of distinct chunk hashes referenced by records.
orphan_chunks: u64Number of orphan chunk files discovered in this run.
orphan_chunk_bytes: u64Number of bytes held by orphan chunk files in this run.
active_quarantine_candidates: u64Number of active quarantine candidates after the run completes.
new_quarantine_candidates: u64Number of quarantine candidates created during this run.
retained_quarantine_candidates: u64Number of previously quarantined candidates still waiting for expiry.
released_quarantine_candidates: u64Number of quarantine candidates released because they were deleted, missing, or reachable again.
deleted_chunks: u64Number of orphan chunk files deleted during this run.
deleted_bytes: u64Number of bytes reclaimed during this run.