pub struct ProviderWebhookResponse {
pub provider: RepositoryProvider,
pub owner: String,
pub repo: String,
pub delivery_id: String,
pub event_kind: String,
pub new_owner: Option<String>,
pub new_repo: Option<String>,
pub revision: Option<String>,
pub affected_file_versions: u64,
pub affected_chunks: u64,
pub applied_holds: u64,
pub retention_seconds: Option<u64>,
}Expand description
Provider webhook handling response.
Fields
provider: RepositoryProviderRepository hosting provider.
owner: StringRepository owner or namespace.
repo: StringRepository name.
delivery_id: StringProvider delivery identifier.
event_kind: StringNormalized webhook event kind.
new_owner: Option<String>New repository owner or namespace when the event renamed the repository.
new_repo: Option<String>New repository name when the event renamed the repository.
revision: Option<String>Updated revision when the event described a push.
affected_file_versions: u64Number of affected immutable file-version records.
affected_chunks: u64Number of distinct affected chunk objects.
applied_holds: u64Number of retention holds inserted or refreshed by the event.
retention_seconds: Option<u64>Retention applied to newly created holds, when the event mutated lifecycle state.