pub struct ReconstructionCacheBenchReport {
pub cold_load_micros: u64,
pub hot_load_micros: u64,
pub response_bytes: u64,
pub cache_hit: bool,
}Expand description
Benchmarks one cold reconstruction load followed by one hot cache hit.
Fields
cold_load_micros: u64Cold reconstruction latency, including the backend load and cache insert.
hot_load_micros: u64Hot reconstruction latency served from cache.
response_bytes: u64Serialized reconstruction-response payload size used by the cache adapter.
cache_hit: boolWhether the second lookup avoided the backend loader.