pub struct ShardMetadataLimits { /* private fields */ }Expand description
Bounded-parser limits for native Xet shard metadata. Bounded-parser limits for native Xet shard metadata.
Implementations
Sourceimpl ShardMetadataLimits
impl ShardMetadataLimits
Sourcepub const fn new(
max_files: NonZero<usize>,
max_xorbs: NonZero<usize>,
max_reconstruction_terms: NonZero<usize>,
max_xorb_chunks: NonZero<usize>,
) -> ShardMetadataLimits
pub const fn new( max_files: NonZero<usize>, max_xorbs: NonZero<usize>, max_reconstruction_terms: NonZero<usize>, max_xorb_chunks: NonZero<usize>, ) -> ShardMetadataLimits
Creates native Xet shard metadata limits.
Sourcepub const fn max_files(self) -> NonZero<usize>
pub const fn max_files(self) -> NonZero<usize>
Returns the maximum file sections accepted in one uploaded shard.
Sourcepub const fn max_xorbs(self) -> NonZero<usize>
pub const fn max_xorbs(self) -> NonZero<usize>
Returns the maximum xorb sections accepted in one uploaded shard.
Sourcepub const fn max_reconstruction_terms(self) -> NonZero<usize>
pub const fn max_reconstruction_terms(self) -> NonZero<usize>
Returns the maximum file reconstruction terms accepted in one uploaded shard.
Sourcepub const fn max_xorb_chunks(self) -> NonZero<usize>
pub const fn max_xorb_chunks(self) -> NonZero<usize>
Returns the maximum xorb chunk records accepted in one uploaded shard.