pub struct StorageMigrationReport {
pub source_backend: String,
pub destination_backend: String,
pub prefix: String,
pub dry_run: bool,
pub scanned_objects: u64,
pub inserted_objects: u64,
pub already_present_objects: u64,
pub copied_bytes: u64,
pub scanned_bytes: u64,
}Expand description
Storage-migration summary.
Fields
source_backend: StringSource object-storage adapter name.
destination_backend: StringDestination object-storage adapter name.
prefix: StringObject-key prefix scanned by the migration.
dry_run: boolWhether the run avoided writes.
scanned_objects: u64Number of source objects scanned.
inserted_objects: u64Number of destination writes that inserted a new object.
already_present_objects: u64Number of destination writes that found an identical object already present.
copied_bytes: u64Number of bytes copied into newly inserted destination objects.
scanned_bytes: u64Number of source bytes inventoried.