LocalFsckReport

Type Alias LocalFsckReport 

pub type LocalFsckReport = FsckReport;
Backward-compatible local fsck report alias.

Aliased Type

pub struct LocalFsckReport {
    pub latest_records: u64,
    pub version_records: u64,
    pub inspected_chunk_references: u64,
    pub inspected_dedupe_shard_mappings: u64,
    pub inspected_reconstructions: u64,
    pub inspected_webhook_deliveries: u64,
    pub inspected_provider_repository_states: u64,
    pub issues: Vec<FsckIssue>,
}

Fields

latest_records: u64

Number of latest records scanned through the configured record store.

version_records: u64

Number of immutable version records scanned through the configured record store.

inspected_chunk_references: u64

Number of chunk references inspected across all records.

inspected_dedupe_shard_mappings: u64

Number of dedupe-shard mappings inspected through the index adapter.

inspected_reconstructions: u64

Number of durable reconstruction rows inspected through the index adapter.

inspected_webhook_deliveries: u64

Number of processed provider webhook deliveries inspected through the index adapter.

inspected_provider_repository_states: u64

Number of provider repository lifecycle states inspected through the index adapter.

issues: Vec<FsckIssue>

Collected integrity issues.