pub enum FsckIssueDetail {
Show 33 variants
MissingVersionRecord {
version_locator: String,
},
OversizedRecordMetadata,
RecordJsonInvalid,
InvalidFileId {
file_id: String,
},
InvalidContentHash {
content_hash: String,
},
RecordPathMismatch {
expected_locator: String,
},
RecordFileIdPathMismatch,
RecordContentHashPathMismatch,
InvalidReconstructionPlan(FsckReconstructionPlanDetail),
InvalidChunkHash {
chunk_hash: String,
},
InvalidXorbHash {
xorb_hash: String,
},
ReferencedByRecord {
record_location: String,
},
ReferencedByNativeXetRecord {
record_location: String,
},
ReferencedByNativeXetXorb {
xorb_location: String,
},
HashMismatch {
expected_hash: String,
observed_hash: String,
},
LengthMismatch {
expected_length: u64,
observed_length: u64,
},
XorbRangeExceededChunkCount {
range_start: u32,
range_end: u32,
chunk_count: usize,
},
MismatchedVersionRecord {
version_locator: String,
},
MappedChunkHash {
chunk_hash: String,
},
MappedChunkHashAbsentFromRetainedShard {
chunk_hash: String,
},
InvalidRetainedShard(InvalidSerializedShardError),
ReconstructionListedUnreadableRow,
ReconstructionContainedNoTerms,
MissingReconstructionXorb {
xorb_hash: String,
},
InvalidQuarantineTimeline {
delete_after_unix_seconds: u64,
first_seen_unreachable_at_unix_seconds: u64,
},
QuarantineReferencedMissingObject,
QuarantineTargetedReachableObject,
InvalidRetentionTimeline {
release_after_unix_seconds: u64,
held_at_unix_seconds: u64,
},
ActiveRetentionHoldReason {
reason: String,
},
ActiveRetentionHoldQuarantined,
WebhookDeliveryTimestampExceeded {
processed_at_unix_seconds: u64,
max_allowed_unix_seconds: u64,
},
ProviderRepositoryIdentityInvalid,
ProviderRepositoryStateTimestampExceeded {
field: ProviderRepositoryStateTimestampField,
timestamp: u64,
max_allowed_unix_seconds: u64,
},
}Expand description
Integrity issue detail.
Variants
MissingVersionRecord
A required version record was missing.
OversizedRecordMetadata
Record metadata exceeded parser limits.
RecordJsonInvalid
Record JSON was invalid.
InvalidFileId
A record file identifier was invalid.
InvalidContentHash
A record content hash was invalid.
RecordPathMismatch
A record was stored at an unexpected location.
RecordFileIdPathMismatch
A record file identifier did not match its path.
RecordContentHashPathMismatch
A record content hash did not match its path.
InvalidReconstructionPlan(FsckReconstructionPlanDetail)
A reconstruction plan was invalid.
InvalidChunkHash
A chunk hash was invalid.
InvalidXorbHash
An xorb hash was invalid.
ReferencedByRecord
An object was referenced by a record.
ReferencedByNativeXetRecord
An object was referenced by a native Xet record.
ReferencedByNativeXetXorb
An object was referenced by a native Xet xorb.
HashMismatch
A hash comparison failed.
LengthMismatch
A length comparison failed.
XorbRangeExceededChunkCount
A native Xet range exceeded the xorb chunk count.
Fields
MismatchedVersionRecord
A latest record differed from its immutable version.
MappedChunkHash
A mapped chunk hash points at a retained shard object.
MappedChunkHashAbsentFromRetainedShard
A mapped chunk hash was absent from its retained shard.
InvalidRetainedShard(InvalidSerializedShardError)
A retained shard was invalid.
ReconstructionListedUnreadableRow
A reconstruction row was listed but unreadable.
ReconstructionContainedNoTerms
A reconstruction contained no terms.
MissingReconstructionXorb
A reconstruction referenced an unregistered xorb.
InvalidQuarantineTimeline
Quarantine delete-after preceded first-seen.
Fields
QuarantineReferencedMissingObject
Quarantine metadata referenced a missing object.
QuarantineTargetedReachableObject
Quarantine metadata targeted a reachable object.
InvalidRetentionTimeline
Retention hold release-after preceded held-at.
Fields
ActiveRetentionHoldReason
Active retention hold reason for a missing held object.
ActiveRetentionHoldQuarantined
Active retention hold coexisted with quarantine state.
WebhookDeliveryTimestampExceeded
Webhook delivery timestamp exceeded the accepted future skew.
Fields
ProviderRepositoryIdentityInvalid
Provider repository identity failed validation.
ProviderRepositoryStateTimestampExceeded
Provider repository state timestamp exceeded the accepted future skew.