pub struct TransferLimiter { /* private fields */ }Expand description
Weighted transfer concurrency limiter based on chunk-equivalent cost.
Implementations
Sourceimpl TransferLimiter
impl TransferLimiter
Sourcepub fn new(
chunk_size_bytes: NonZeroUsize,
max_in_flight_chunks: NonZeroUsize,
) -> Self
pub fn new( chunk_size_bytes: NonZeroUsize, max_in_flight_chunks: NonZeroUsize, ) -> Self
Creates a transfer limiter that budgets concurrent response work in chunk-equivalent permits.
Sourcepub async fn acquire_bytes(
&self,
total_bytes: u64,
) -> Result<OwnedSemaphorePermit, ServerError>
pub async fn acquire_bytes( &self, total_bytes: u64, ) -> Result<OwnedSemaphorePermit, ServerError>
Acquires permits for a transfer with the supplied byte length.
Errors
Returns ServerError when the limiter capacity cannot be represented or the
semaphore has been closed.